pub enum EditableError {
CannotDoAction(String),
CannotUndoAction(String),
Custom(Box<dyn Error>),
}Expand description
An error that can occur during editing operations.
Variants
CannotDoAction(String)
An error indicating that an action cannot be performed.
CannotUndoAction(String)
An error indicating that an action cannot be undone.
Custom(Box<dyn Error>)
A custom error.